/*
   ZoranIOCTL.h

   ZORAN ZR36120 module driver.
   Copyright (C) 1997  Vincent Labie (try ivsparis@pratique.fr with
				      for Vincent Labie in the suject)

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef	ZORANIOCTL_H
#define	ZORANIOCTL_H

#include <sys/ioctl.h>

/**********************************************************************************************************************/

#define		ZORAN_DUMP_REG			0x0001
#define		ZORAN_CAP_PARAMS		0x0002

#define		ZORAN_CAPMODE_STOP		0x0101
#define		ZORAN_CAPMODE_CONTINOUS		0x0102
#define		ZORAN_CAPMODE_3CONTINOUS	0x0103
#define		ZORAN_CAPMODE_GRAB		0x0104
#define		ZORAN_CAP_IS_GRAB		0x0105
#define		ZORAN_CAP_NEW_GRAB		0x0106
#define		ZORAN_CAP_NEW_USER		0x0107
#define		ZORAN_CAPMODE_3CONTINOUSHACK	0x0108

	/*	order is important!	*/
#define		ZORAN_AUTO			0x0201
#define		ZORAN_NTSC			0x0202
#define		ZORAN_PAL			0x0203
#define		ZORAN_SECAM			0x0204
#define		ZORAN_BW60HZ			0x0205
#define		ZORAN_BW50HZ			0x0206

	/*	order is important!	*/
#define		ZORAN_HUE			0x0301
#define		ZORAN_GAIN			0x0302
#define		ZORAN_SATURATION		0x0303
#define		ZORAN_CONTRAST			0x0304
#define		ZORAN_BRIGHTNESS		0x0305

	/*	order is important!	*/
#define		ZORAN_CVBS1			0x0401
#define		ZORAN_CVBS2			0x0402
#define		ZORAN_CVBS3			0x0403
#define		ZORAN_CVBS4			0x0404
#define		ZORAN_CVBS5			0x0405
#define		ZORAN_CVBS6			0x0406
#define		ZORAN_Y1C1			0x0407
#define		ZORAN_Y2C2			0x0408
#define		ZORAN_Y3C3			0x0409
#define		ZORAN_CVBS1_NCT			0x040a
#define		ZORAN_CVBS2_NCT			0x040b
#define		ZORAN_CVBS3_NCT			0x040c
#define		ZORAN_CVBS4_NCT			0x040d
#define		ZORAN_CVBS5_NCT			0x040e
#define		ZORAN_CVBS6_NCT			0x040f

#define		ZORAN_I2C_READ			0x0501
#define		ZORAN_I2C_WRITE			0x0502

#define		NB_MAX_ZORAN_SLOT	32

enum	ZR_REDUCEMODE
		{
		ZRM_TOOSMALL=-1,
		ZRM_CROP,
		ZRM_SCALE,
		ZRM_TOOLARGE
		};

enum	ZR_HFILTER
		{
		ZHF_TOOSMALL=-1,
		ZHF_NONE,
		ZHF_3L3C,
		ZHF_4L4C,
		ZHF_5L4C,
		ZHF_TOOLARGE
		};

enum	ZR_PIXEL
		{
		ZPX_TOOSMALL=-1,
		ZPX_YUV422,
		ZPX_RGB888_PACK32,
		ZPX_RGB565,
		ZPX_RGB555,
		ZPX_RGB888_PACK24,
		ZPX_TOOLARGE
		};

enum	ZR_ENDIAN
		{
		ZEN_TOOSMALL=-1,
		ZEN_LITTLEENDIAN,
		ZEN_BIGENDIAN,
		ZEN_TOOLARGE
		};

enum	ZR_FIELD
		{
		ZFI_TOOSMALL=-1,
		ZFI_NORMAL,
		ZFI_DUPLICATE,
		ZFI_TOOLARGE
		};

enum	ZR_ERRDIF
		{
		ZED_TOOSMALL=-1,
		ZED_NONE,
		ZED_ACTIVE,
		ZED_TOOLARGE
		};

// Capture parameter struct. a good idea is to memset it to 0 before use...
// that way, futur extension will not break our code. all default are 0.
typedef	struct
	{
	int			CapWidth;				// wanted picture width
	int			CapHeight;				// wanted picture height
	int			CapScanLineSize;			// wanted picture line size
	enum ZR_REDUCEMODE	ZRReduceMode;				// wanted picture scale down mode
	enum ZR_PIXEL		ZRPixel;				// wanted picture output pixel
	enum ZR_ENDIAN		ZREndian;				// wanted picture bytes order
	enum ZR_FIELD		ZRField;				// wanted picture duplicated
	enum ZR_HFILTER		ZRHFilter;				// filter type
	enum ZR_ERRDIF		ZRErrDif;				// wanted error diffusion for 15/16bpp
	int			NbSlot;					// wanted Nb Slot
	long			TabSlotOffset[NB_MAX_ZORAN_SLOT];	// returned Slot offset, filled by driver
	}		ZR_CAP_PARAMS;

typedef	struct
	{
	int		I2CAdr;
	int		I2CSubAdr;	// first I2C byte send. -1 for none
	u_int		NbByte;
	u_char *	TabByte;
	}	ZR_I2C_ACCESS;

/**********************************************************************************************************************/
#endif	//ZORANIOCTL_H
